@@ -322,6 +322,7 @@ __all__ = (
     "StatusTypeType",
     "SubnetAvailableWaiterName",
     "SubnetCidrBlockStateCodeType",
+    "SubnetCidrReservationTypeType",
     "SubnetStateType",
     "SummaryStatusType",
     "SystemStatusOkWaiterName",
@@ -1342,6 +1343,7 @@ SubnetAvailableWaiterName = Literal["subnet_available"]
 SubnetCidrBlockStateCodeType = Literal[
     "associated", "associating", "disassociated", "disassociating", "failed", "failing"
 ]
+SubnetCidrReservationTypeType = Literal["explicit", "prefix"]
 SubnetStateType = Literal["available", "pending"]
 SummaryStatusType = Literal["impaired", "initializing", "insufficient-data", "not-applicable", "ok"]
 SystemStatusOkWaiterName = Literal["system_status_ok"]
